cors

package
v1.1.3 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jul 10, 2025 License: MIT Imports: 4 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func New

func New(config ...Config) pine.Middleware

func ParseMethod

func ParseMethod(method string) bool

func SetCors

func SetCors(c *pine.Ctx, cfg Config) *pine.Ctx

Types

type Config

type Config struct {
	// AllowedOrigins is a list of origins a cross-domain request can be executed from.
	// If set to "*", all origins will be allowed.
	// An origin may contain a wildcard (*) to replace 0 or more characters
	// (i.e.: http://*.domain.com). Usage of wildcards implies a small performance penalty.
	// Only one wildcard can be used per origin.
	//
	// Default value is []string{"*"}
	AllowedOrigins []string

	// AllowedMethods is a list of methods the client is allowed to use with
	// cross-domain requests.
	//
	// Default value is simple methods ["GET", "POST", "PUT", "PATCH", "DELETE"]
	// This is the same as in the server.config.DefaultMethods
	AllowedMethods []string

	// AllowedHeaders is list of non simple headers the client is allowed to use with
	// cross-domain requests.
	//
	// If the special "*" value is present in the list, all headers will be allowed.
	// Default value is "Content-Type, Authorization"
	AllowedHeaders string

	// ExposedHeaders indicates which headers are safe to expose to the API of a CORS
	// API specification
	//
	// Default value is ""
	ExposedHeaders string

	// AllowedCredentials refers to whether the request can include user credentials
	// like cookies, HTTP authentication or client side SSL certificates.
	//
	// Default value is false
	AllowCredentials bool

	// MaxAge referes to how long the results of a preflight request can be cached
	// by the browser. This is always in seconds.
	//
	// Default value is 0, i.e. the browser does not cache the result.
	// if set to 0, max-age is set to 5 seconds which is the default value set
	// by most browsers.
	MaxAge int
}

Jump to